@@ -2,6 +2,7 @@
 import sys
 import gffutils
 import pandas as pd 
+from tqdm import tqdm 
 from Bio import SeqIO
 from Bio.Seq import Seq
 from Bio.SeqRecord import SeqRecord
@@ -262,6 +263,8 @@ class uORF(object):
         """uorf finder main program, return a dict"""
         uORF_dict = defaultdict(list)
         # start_codon_position means the first base position in matural_transcript
+        if self.cds not in self.mt:
+            return uORF_dict
         start_codon_position = self.mt.index(self.cds)
         # stop_codon_position means the last base position in matural transcript
         stop_codon_position = start_codon_position + len(self.cds)
@@ -389,16 +392,19 @@ def get_uorf(args):
     """
     db = gffutils.FeatureDB(args.database, keep_order=True)
     # csv
-    uORF_seq = pd.DataFrame(columns=_uORF_csv_header)
+    # uORF_seq = pd.DataFrame(columns=_uORF_csv_header)
+    uORF_seq_list = []
     # gff
     uORF_gff = open(args.output,'w')
     # fasta
     uorf_record = []
     index = 0
     mRNA_str = mRNA_type(args.style) 
-    # not specify the transcript id
+    # loop all transcripts in genome
     if not args.transcript:
-        for t in db.features_of_type(mRNA_str, order_by='start'):
+        for t in tqdm(db.features_of_type(mRNA_str, order_by='start'), \
+                      total = len(list(db.features_of_type(mRNA_str, order_by='start'))), \
+                      ncols = 80, desc = "uORF Processing :"):
             # primary transcript (pt) 是基因组上的转录本的序列，
             # 有的会包括intron，所以提取的序列和matural transcript 不一致
             # print(t)
@@ -428,15 +434,23 @@ def get_uorf(args):
             # procedure-oriented
             # uORF_dict = uorf_procedure_oriented(t.id, t.chrom, t.strand, mt, cds)
             # objected-oriented
+            if mt == cds: # not contain uORF
+                continue
+            if len(cds) % 3 != 0: # CDS error
+                continue
             uORF_ = uORF(t.id, t.chrom, t.strand, mt, cds)
             uORF_dict = uORF_.uorf_parse()
+            if len(uORF_dict) == 0: # CDS error
+                continue
             # loop for type1, type2 and type3
             for key in sorted(uORF_dict.keys()):
                 # print(key,len(uORF_dict[key]))
                 for it in uORF_dict[key]:
                     # csv output format 
                     if args.output_format == 'csv':
-                        uORF_seq.loc[index] = it
+                        # uORF_seq.loc[index] = it
+                        # dict 
+                        uORF_seq_list.append(dict((_uORF_csv_header[i],it[i]) for i in range(len(_uORF_csv_header))))
                         index += 1
                     elif args.output_format == 'fasta':
                         uorf_id = ".".join(map(str,[it[0], it[4], it[5], it[6]]))
@@ -461,6 +475,7 @@ def get_uorf(args):
                             uORF_gff.write(feature_line+"\n")
         # output file 
         if args.output_format == 'csv':
+            uORF_seq = pd.DataFrame.from_dict(uORF_seq_list)
             uORF_seq.to_csv(args.output, sep=',', index=False)
         elif args.output_format == 'gff':
             uORF_gff.close()
@@ -468,6 +483,7 @@ def get_uorf(args):
             with open(args.output,'w') as handle:
                 SeqIO.write(uorf_record, handle, "fasta")
     else:
+        # specify the transcript id; only one transcript
         for t in db.features_of_type(mRNA_str, order_by='start'):
             # primary transcript (pt) 是基因组上的转录本的序列，
             # 有的会包括intron，所以提取的序列和matural transcript 不一致
@@ -507,16 +523,28 @@ def get_uorf(args):
                 # procedure-oriented 
                 # uORF_dict = uorf_procedure_oriented(t.id, t.chrom, t.strand, mt, cds)
                 # objected-oriented
+                if mt == cds:  # not contain uORF
+                    continue
+                if len(cds) % 3 != 0: # CDS error
+                    continue
                 uORF_ = uORF(t.id, t.chrom, t.strand, mt, cds)
                 uORF_dict = uORF_.uorf_parse()
+                if len(uORF_dict) == 0:  # CDS error
+                    continue
                 uorf_location_genome = [] # for schematic on genome # 3D list 
                 for key in sorted(uORF_dict.keys()):
                     # print(key,len(uORF_dict[key]))
                     for it in uORF_dict[key]:
                         # csv output format 
                         if args.output_format == 'csv':
-                            uORF_seq.loc[index] = it
+                            # uORF_seq.loc[index] = it
+                            # dict is fastest way 
+                            uORF_seq_list.append(dict((_uORF_csv_header[i],it[i]) for i in range(len(_uORF_csv_header))))
                             index += 1
+                            # for schematic on genome
+                            gff = GFF(exons_list, it, 'uORF')
+                            ex_locations = gff.uorf_exons_location()
+                            uorf_location_genome.append(ex_locations)
                         elif args.output_format == 'fasta':
                             uorf_id = ".".join(map(str,[it[0], it[4], it[5], it[6]]))
                             seq = it[8] # it[8] is a Seq type
@@ -529,7 +557,12 @@ def get_uorf(args):
                                                                         it[3].split('-')[1])
                             uorfRecord = SeqRecord(seq, id=uorf_id.replace('transcript:',''), description=desc)
                             uorf_record.append(uorfRecord)
+                            # for schematic on genome
+                            gff = GFF(exons_list, it, 'uORF')
+                            ex_locations = gff.uorf_exons_location()
+                            uorf_location_genome.append(ex_locations) 
                         elif args.output_format == 'gff':
+                            # for schematic on genome
                             gff = GFF(exons_list, it, 'uORF')
                             uorf_gff_line,features_gff_lines = gff.parse()
                             ex_locations = gff.uorf_exons_location()
@@ -559,6 +592,7 @@ def get_uorf(args):
                     figure.draw() 
                 # file out
                 if args.output_format == 'csv':
+                    uORF_seq = pd.DataFrame.from_dict(uORF_seq_list)
                     uORF_seq.to_csv(args.output, sep=',', index=False)
                 elif args.output_format == 'gff':
                     uORF_gff.close()
